# Generated by roxygen2: do not edit by hand

export(add_intertidal_flag)
export(add_season_column)
export(add_shellfish_classification)
export(add_suitability_ci)
export(analyse_connectivity)
export(area_summary)
export(assess_gear_feasibility)
export(auto_tidal_correct)
export(calculate_aragonite)
export(check_exclusions)
export(classify_substrate_from_backscatter)
export(compare_species)
export(compare_surveys)
export(composite_seasonal)
export(correct_to_chart_datum)
export(detect_season)
export(estimate_chlorophyll_from_backscatter)
export(estimate_fetch)
export(export_contours)
export(export_geotiff)
export(export_qml_style)
export(fetch_live_environmental_data)
export(generate_report)
export(generate_summary_pdf)
export(get_species_tolerances)
export(get_tolerance_posteriors)
export(identify_resilient_sites)
export(interpolate_survey)
export(list_species)
export(load_tolerance_update)
export(merge_sensor_data)
export(oystermapR_help)
export(oystermapR_live_config)
export(parse_opendrift_connectivity)
export(permutation_importance)
export(plot_tolerance)
export(predict_oyster)
export(project_suitability)
export(qc_survey_data)
export(read_aanderaa_csv)
export(read_generic_csv)
export(read_nortek_adcp)
export(read_nortek_aquadopp)
export(read_rdi_adcp)
export(read_sonar_tif)
export(read_soundings_xyz)
export(reset_tolerance_update)
export(save_tolerance_update)
export(score_anthropogenic_disturbance)
export(score_disease_risk)
export(score_economic_viability)
export(score_hab_risk)
export(score_larval_connectivity)
export(score_locations)
export(score_predation_risk)
export(score_sediment_stability)
export(score_settlement)
export(score_wave_exposure)
export(sensitivity_analysis)
export(smooth_suitability)
export(spatial_block_cv)
export(stack_surveys)
export(tidal_port_info)
export(update_species_tolerances)
export(validate_against_records)
export(variable_impact)
importFrom(cli,cli_abort)
importFrom(cli,cli_code)
importFrom(cli,cli_h2)
importFrom(cli,cli_h3)
importFrom(cli,cli_inform)
importFrom(cli,cli_rule)
importFrom(cli,cli_warn)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,case_when)
importFrom(dplyr,coalesce)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,full_join)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,recode)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(grDevices,colorRampPalette)
importFrom(graphics,barplot)
importFrom(rlang,`%||%`)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,dnorm)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,optim)
importFrom(stats,predict)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(tools,file_ext)
importFrom(utils,browseURL)
importFrom(utils,read.csv)
