# oystermapR — Literature References

This file documents the primary scientific literature underpinning the
ecological models, scoring parameters, and methods implemented in oystermapR.

---

## Core AHP Suitability Framework

Saaty T.L. (1980) *The Analytic Hierarchy Process*. McGraw-Hill, New York.

Store R.H. & Jokimäki J. (2003) A GIS-based multi-scale approach to habitat
suitability modelling. *Ecological Modelling* 169:1–15.

---

## Species Tolerance Parameters

### *Ostrea edulis* (European flat oyster)

Pogoda B. et al. (2019) The Native Oyster Restoration Alliance (NORA) and the
Berlin Oyster Recommendation: moving from advocacy to concerted action to
restore a key ecosystem engineer. *Aquatic Living Resources* 32:13.
doi:10.1051/alr/2019012

Pogoda B. et al. (2023) Assessment of European flat oyster *Ostrea edulis*
(Linnaeus, 1758) habitat suitability in the North Sea and adjacent waters.
*Aquatic Conservation: Marine and Freshwater Ecosystems* 33(9):940-960.
doi:10.1002/aqc.3928

Shelmerdine R.L. & Leslie B. (2009) Defining habitat thresholds for the
European flat oyster *Ostrea edulis*: a review of available literature.
Scottish Natural Heritage Commissioned Report No. 360.

Henderson J. & Richardson C.A. (1994) Aspects of the reproductive biology of
flat oysters (*Ostrea edulis*) from the Solent. *J Mar Biol Assoc UK* 74:781–798.

OSPAR Commission (2013) Descriptive definition of North-East Atlantic habitats:
Native oyster beds. OSPAR Convention for the Protection of the Marine Environment
of the North-East Atlantic.

Laing I. & Walker P. (2003) The status of *Ostrea edulis* in England and Wales.
*Hydrobiologia* 188:29–42.

### *Magallana gigas* (Pacific oyster)

Cognie B. et al. (2001) Selection in situ of large suspended particles by the
oyster *Crassostrea gigas*. *Mar Ecol Prog Ser* 218:105–116.

Bayne B.L. (2017) *Biology of Oysters*. Academic Press. ISBN: 978-0-12-803471-4.

Ruesink J.L. et al. (2005) Introduction of non-native oysters: ecosystem effects
and restoration implications. *Annual Review of Ecology, Evolution, and Systematics*
36:643–689.

Breitburg D.L. (2002) Effects of hypoxia, and the balance between hypoxia and
enrichment, on coastal fishes and fisheries. *Estuaries* 25(4):767-781.
doi:10.1007/BF02804904

### *Crassostrea angulata* (Portuguese oyster)

Flores-Vergara C. et al. (2004) Reproduction of the Pacific oyster *Crassostrea
gigas* (Thunberg, 1793) in the northwest coast of Baja California, Mexico.
*Cienc Mar* 30:19–31.

Ojea J. et al. (2011) First documented occurrence of *Crassostrea angulata*
(Lamarck, 1819) in North Atlantic waters after its recovery in the Tagus Estuary
(SW Iberian Peninsula). *Aquaculture Research* 41:2468–2472.

da Silva P.M. et al. (2009) The feasibility of repopulating Portuguese oyster
(*Crassostrea angulata*) in southern Portugal. *Aquaculture* 286:279–284.

### *Ostrea stentina* (Denticulate flat oyster)

Sendra E.D. (2022) Spat production and early growth of *Ostrea stentina* from
Mar Menor (SE Spain). *Aquaculture Reports* 22:100989.

González-Wangüemert M. et al. (2019) Reconsidering the cryptic species
*Ostrea stentina* from Mediterranean and Atlantic waters. *Scientia Marina*
83:55–65.

Ramos-Esplá A.A. et al. (2022) Conservation status of *Pinna nobilis* and
associated bivalves in the Mar Menor lagoon. *Mediterranean Marine Science*
23:1–18.

### *Ostrea lurida* (Olympia oyster)

Trimble A.C. et al. (2009) Restoring the Olympia oyster *Ostrea lurida* Carpenter
1864 to Puget Sound, Washington, USA. *Journal of Shellfish Research* 28:43–53.

Kimbro D.L. et al. (2019) Restoration of Olympia oyster habitat in the western
United States. *Restoration Ecology* 27:984–994.

Henderson S. et al. (2012) Determination of thermal tolerance for Olympia oysters
(*Ostrea lurida*). *Pacific Cooperative Studies Unit Tech Rep*.

Polson M.P. & Zacherl D.C. (2009) Geographic distribution and intertidal
population status for the Olympia oyster, *Ostrea lurida* Carpenter 1864, from
Alaska to Baja. *Journal of Shellfish Research* 28:69–76.

Wasson K. et al. (2015) Lessons learned from Olympia oyster restoration in
Elkhorn Slough, California. *San Francisco Estuary and Watershed Science* 13(2).

### *Crassostrea virginica* (Eastern oyster)

Kennedy V.S., Newell R.I.E. & Eble A.F. (eds.) (1996) *The Eastern Oyster:
Crassostrea virginica*. Maryland Sea Grant College, College Park.
ISBN: 0-943676-39-4.

Shumway S.E. (1996) Natural environmental factors. In: Kennedy V.S. et al.
(eds.) *The Eastern Oyster: Crassostrea virginica*. Maryland Sea Grant College.
pp. 467-513.

### *Saccostrea glomerata* (Sydney rock oyster)

Nell J.A. (2002) Farming the Sydney rock oyster (*Saccostrea glomerata*) in
Australia: the adoption of new technology. *Reviews in Fisheries Science*
10(3-4):153-176. doi:10.1080/20026491051728

Dove M.C. & Sammut J. (2007) Impacts of estuarine acidification on the
survival and growth of Sydney rock oysters (*Saccostrea glomerata*).
*Journal of Shellfish Research* 26(4):1169-1176.
doi:10.2983/0730-8000(2007)26[1169:IOEAOT]2.0.CO;2

Parker L.M. et al. (2011) Thermal response of *Saccostrea glomerata* to
ocean warming and acidification. *Journal of Experimental Marine Biology and
Ecology* 400(1-2):48-55. doi:10.1016/j.jembe.2011.02.014

### *Magallana sikamea* (Kumamoto oyster)

Langdon C. & Robinson A.M. (1996) Aquaculture potential of the Suminoe oyster
(*Crassostrea ariakensis* Fugita 1913). *Aquaculture* 144:321-338.
doi:10.1016/S0044-8486(96)01295-X

### *Magallana ariakensis* (Suminoe oyster)

Zhang G. et al. (2012) The oyster genome reveals stress adaptation and
complexity of shell formation. *Nature* 490:49-54. doi:10.1038/nature11413

Calvo G.W. et al. (2001) A comparative field study of four oyster species:
*Crassostrea gigas*, *Crassostrea ariakensis*, *Crassostrea virginica* and
*Ostrea edulis* -- intermediate-scale grow-out in Virginia.
*Journal of Shellfish Research* 20(1):175-185.

Meng J. et al. (2025) Characterization of the thermal tolerance limits in
*Magallana ariakensis*. *Biology* 14(3):311.
doi:10.3390/biology14030311

### *Crassostrea hongkongensis* (Hong Kong oyster)

Ren J. et al. (2016) Comparative mitogenomics reveals gene rearrangements and
phylogenetic relationships among five *Crassostrea* species.
*Marine Biotechnology* 18(6):712-724. doi:10.1007/s10126-016-9686-8

Liu Z. et al. (2022) Complete mitochondrial genome and phylogenetic position
of *Crassostrea hongkongensis*. *Molecular Biology Reports* 49:3411-3418.
doi:10.1007/s11033-021-07016-2

Zhong X. et al. (2014) Genome-wide SNPs reveal the evolutionary history of
*Crassostrea* oysters. *PLoS ONE* 9(10):e108256.
doi:10.1371/journal.pone.0108256

### *Crassostrea nippona* (Iwagaki oyster)

Hamaguchi M. et al. (2000) Reproductive cycle of *Crassostrea nippona*
(Seki, 1934) in Ago Bay, central Japan. *Journal of Shellfish Research*
19(2):851-858.

Fujimoto S. et al. (2017) Mass selection for shell height in *Crassostrea
nippona*: genetic parameters and selection response. *Aquaculture* 478:87-93.
doi:10.1016/j.aquaculture.2017.05.014

### *Crassostrea belcheri* (Tropical rock oyster)

Tiensongrusmee B. & Pongsri C. (1978) Oyster culture in Thailand. In:
Pillay T.V.R. & Dill W.A. (eds.) *Advances in Aquaculture*. Fishing News
Books, Farnham. pp. 481-485.

FAO (2007) Regional review on status and trends in aquaculture development in
Asia-Pacific, 2005. FAO Fisheries Circular No. 1017. Rome: FAO.

### *Ostrea chilensis* (Chilean oyster)

Jeffs A. et al. (2023) Dredge oyster (*Ostrea chilensis*) aquaculture in
New Zealand: current status and future prospects. *New Zealand Journal of
Marine and Freshwater Research* 57(S1):S52-S72.
doi:10.1080/00288330.2023.2197004

Paul-Burke K. & Burke J. (2019) Using Maori knowledge to assist understanding
and management of tipa (*Ostrea chilensis*) in declining habitat in Foveaux
Strait, New Zealand. *New Zealand Journal of Marine and Freshwater Research*
53(2):262-276. doi:10.1080/00288330.2018.1539487

### *Ostrea denselamellosa* (Korean flat oyster)

Park K.I. et al. (2012) Reproductive cycle of the Korean flat oyster *Ostrea
denselamellosa* (Lischke, 1869) in Gamak Bay, Korea. *Journal of Shellfish
Research* 31(4):947-954. doi:10.2983/035.031.0403

---

## Spatial Analysis and Terrain Derivatives

Horn B.K.P. (1981) Hill shading and the reflectance map. *Proceedings of the
IEEE* 69(1):14-47. doi:10.1109/PROC.1981.11918

---

## Validation Methods

Tukey J.W. (1977) *Exploratory Data Analysis*. Addison-Wesley, Reading MA.
ISBN: 0-201-07616-0.
(Outer-fence IQR rule used for statistical outlier detection in `qc_survey_data()`.)

Youden W.J. (1950) Index for rating diagnostic tests. *Cancer* 3(1):32–35.
doi:10.1002/1097-0142(1950)3:1<32::AID-CNCR2820030106>3.0.CO;2-3
(Youden's J = sensitivity + specificity − 1; reported by `validate_against_records()`.)

Roberts D.R. et al. (2017) Cross-validation strategies for data with temporal,
spatial, hierarchical, or phylogenetic structure. *Ecography* 40:913–929.
doi:10.1111/ecog.02881

Hijmans R.J. (2012) Cross-validation of species distribution models: removing
spatial sorting bias and calibration with a null model. *Ecology* 93:679–688.

Allouche O. et al. (2006) Assessing the accuracy of species distribution models:
prevalence, kappa and the true skill statistic (TSS). *J Appl Ecol* 43:1223–1232.

Zurell D. et al. (2020) A standard protocol for reporting species distribution
models. *Ecography* 43:1261–1277. doi:10.1111/ecog.04960

---

## Bayesian Parameter Updating

Gelman A. et al. (2013) *Bayesian Data Analysis*, 3rd ed. CRC Press, Boca Raton.

Rue H. et al. (2009) Approximate Bayesian inference for latent Gaussian models
using integrated nested Laplace approximations. *J R Statist Soc B* 71:319–392.

Dorazio R.M. (2012) Predicting the geographic distribution of a species from
presence-only data subject to detection errors. *Biometrics* 68:1303–1312.

---

## Variable Importance

Breiman L. (2001) Random Forests. *Machine Learning* 45:5–32.

Elith J. et al. (2008) A working guide to boosted regression trees. *J Anim
Ecol* 77:802–813.

Thuiller W. et al. (2009) BIOMOD — a platform for ensemble forecasting of
species distributions. *Ecography* 32:369–373.

---

## Wave Exposure and Sediment Stability

Hasselmann K. et al. (1973) Measurements of wind-wave growth and swell decay
during the Joint North Sea Wave Project (JONSWAP). *Dtsch Hydrogr Z Suppl A8*:
1–95.

Battjes J.A. & Janssen J.P.F.M. (1978) Energy loss and set-up due to breaking
of random waves. In: *Proceedings 16th International Coastal Engineering
Conference*. ASCE, pp. 569–587.

Grant W.D. & Madsen O.S. (1979) Combined wave and current interaction with a
rough bottom. *Journal of Geophysical Research* 84(C4):1797–1808.
doi:10.1029/JC084iC04p01797

van Rijn L.C. (1984) Sediment transport, Part I: bed load transport. *J
Hydraulic Eng* 110:1431–1456.

Soulsby R.L. (1997) *Dynamics of Marine Sands*. Thomas Telford, London.
ISBN: 0-7277-2584-X.

---

## HAB Risk

Gallacher S. et al. (2019) Predicting harmful algal blooms at Scottish shellfish
aquaculture farms. *ICES J Mar Sci* 76:3203–3213.

ICES WGHABD (2022) Working Group on Harmful Algal Bloom Dynamics.
CM 2022/HAPISG:03.

Trainer V.L. et al. (2020) Parallels and contrasts in the seasonality of
Pseudo-nitzschia species. *Harmful Algae* 96:101826.

---

## Anthropogenic Disturbance

Eigaard O.R. et al. (2017) The footprint of bottom trawling in European waters:
distribution, intensity, and seabed integrity. *ICES J Mar Sci* 74:1700–1710.

Hiddink J.G. et al. (2017) Global analysis of depletion and recovery of seabed
biota after bottom trawling disturbance. *PNAS* 114:8301–8306.

ICES WGSFD (2022) Working Group on Spatial Fisheries Data. CM 2022/HAPISG:17.

---

## Disease Risk

Engelsma M.Y. et al. (2014) An outbreak of Bonamia ostreae in *Ostrea edulis*
from the Grevelingenmeer, The Netherlands. *Dis Aquat Organ* 109:25–32.

Carrasco N. et al. (2015) Oyster herpesvirus (OsHV-1) detection in flat oysters
from Spanish coast. *Bull Eur Assoc Fish Pathol* 35:235–243.

ICES Advisory Committee (2023) Advice on *Bonamia ostreae* and *Marteilia
refringens* in European shellfish. ICES Advice 2023.

---

## Gear Feasibility and Economic Viability

OSPAR Commission (2010) Background Document for Subtidal Oyster Beds.
OSPAR Biodiversity Series, Publication No. 463.

Kaiser M.J. et al. (2000) Chronic fishing disturbance has changed shelf sea
benthic community structure. *J Anim Ecol* 69:494–503.

---

## Shellfish Water Quality Classification

European Commission (2004) Regulation (EC) No 854/2004 laying down specific
rules for the organisation of official controls on products of animal origin
intended for human consumption. *Off J Eur Union* L226:83–127.

Food Standards Agency (2024) Shellfish classified harvesting areas — England.
https://www.food.gov.uk/business-guidance/shellfish-classification.

---

## Larval Dispersal and Population Connectivity

Cowen R.K. & Sponaugle S. (2009) Larval dispersal and marine population
connectivity. *Annual Review of Marine Science* 1:443–466.

Siegel D.A. et al. (2008) The stochastic nature of larval connectivity among
nearshore marine populations. *PNAS* 105:8974–8979.

Robins P.E. et al. (2017) Empirical and modelled larval dispersal for oysters:
implications for restoration. *Journal of Applied Ecology* 54:1699–1710.
doi:10.1111/1365-2664.12854

Ayata S.D. et al. (2010) Dispersal in a nutrient-limited ocean: modelling
larval connectivity in Atlantic and Pacific benthic invertebrates.
*Ecology Letters* 13:1547–1558.

Woolmer A.P. et al. (2009) European flat oyster *Ostrea edulis* L. stock
assessment and potential for restoration in the Firth of Clyde, Scotland.
*Journal of Shellfish Research* 28:107–116.

Levin L.A. (2006) Recent progress in understanding larval dispersal: new
directions and digressions. *Integrative and Comparative Biology* 46:282–297.

---

## Tidal Correction

Pugh D.T. (1987) *Tides, Surges and Mean Sea Level*. Wiley, Chichester.
ISBN: 0-471-91505-X.
