% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ingest_sensors.R
\name{.auto_map_columns}
\alias{.auto_map_columns}
\title{Automatic column name matching for common sensor exports}
\usage{
.auto_map_columns(df, verbose = TRUE)
}
\description{
Automatic column name matching for common sensor exports
}
\keyword{internal}
