% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/validate.R
\name{.ascii_roc}
\alias{.ascii_roc}
\title{Print a simple ASCII ROC curve to the console}
\usage{
.ascii_roc(fpr, tpr, auc, width = 50, height = 20)
}
\description{
Print a simple ASCII ROC curve to the console
}
\keyword{internal}
