% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayesian_update.R
\name{.get_cached_tolerances}
\alias{.get_cached_tolerances}
\title{Retrieve cached tolerance list (or NULL if not updated)}
\usage{
.get_cached_tolerances(species)
}
\description{
Retrieve cached tolerance list (or NULL if not updated)
}
\keyword{internal}
