% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict_oyster.R
\name{.find_col_any}
\alias{.find_col_any}
\title{Find first matching column (case-insensitive)}
\usage{
.find_col_any(df, candidates)
}
\description{
Find first matching column (case-insensitive)
}
\keyword{internal}
