% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/season_utils.R
\name{add_season_column}
\alias{add_season_column}
\title{Detect season for each row in a dataframe}
\usage{
add_season_column(df, date_col = NULL, lat_col = "lat")
}
\arguments{
\item{df}{A dataframe containing at minimum a date column and a latitude column.}

\item{date_col}{Name of the date column (default \code{"date"}).}

\item{lat_col}{Name of the latitude column (default \code{"lat"}).}
}
\value{
The input dataframe with an additional column \code{season}.
}
\description{
Vectorised wrapper around \code{\link[=detect_season]{detect_season()}} for use on dataframes.
}
