% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/species_tolerances.R
\name{list_species}
\alias{list_species}
\title{List all supported species}
\usage{
list_species()
}
\value{
Named character vector: names = latin names, values = species keys.
}
\description{
List all supported species
}
\examples{
list_species()
}
