% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/predict_oyster.R
\name{.standardise_coords}
\alias{.standardise_coords}
\title{Standardise coordinate column names to lat/lon}
\usage{
.standardise_coords(df)
}
\description{
Standardise coordinate column names to lat/lon
}
\keyword{internal}
