% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/species_tolerances.R
\name{get_species_tolerances}
\alias{get_species_tolerances}
\title{Get species tolerance parameters}
\usage{
get_species_tolerances(species)
}
\arguments{
\item{species}{Character. Species key (e.g. \code{"ostrea_edulis"}), latin name,
or common name (partial, case-insensitive).}
}
\value{
Named list of tolerance parameters for the species.
}
\description{
Get species tolerance parameters
}
\examples{
tol <- get_species_tolerances("ostrea_edulis")
tol$exclusions$temperature
}
