% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayesian_update.R
\name{.rwmh}
\alias{.rwmh}
\title{Random-Walk Metropolis-Hastings MCMC sampler}
\usage{
.rwmh(
  log_post,
  theta_init,
  n_iter,
  n_warmup,
  proposal_sd,
  lower,
  upper,
  verbose = TRUE
)
}
\description{
Random-Walk Metropolis-Hastings MCMC sampler
}
\keyword{internal}
