% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/score_variables.R
\name{.score_categorical}
\alias{.score_categorical}
\title{Score a categorical variable}
\usage{
.score_categorical(x, params)
}
\description{
Score a categorical variable
}
\keyword{internal}
