% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayesian_update.R
\name{.numerical_hessian}
\alias{.numerical_hessian}
\title{Compute numerical Hessian by finite differences (central differences)}
\usage{
.numerical_hessian(f, theta, h = 1e-04)
}
\description{
Compute numerical Hessian by finite differences (central differences)
}
\keyword{internal}
