% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ingest_sensors.R
\name{.mode}
\alias{.mode}
\title{Mode helper (most common value in a vector)}
\usage{
.mode(x)
}
\description{
Mode helper (most common value in a vector)
}
\keyword{internal}
