% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tidal_correction.R
\name{.haversine_km}
\alias{.haversine_km}
\title{Haversine distance in km between two WGS84 points}
\usage{
.haversine_km(lat1, lon1, lat2, lon2)
}
\description{
Haversine distance in km between two WGS84 points
}
\keyword{internal}
